#include <Wire.h>
#include <LiquidCrystal_PCF8574.h>
#include <Bounce.h>

const int TRIGGER_PIN = 12;
const int NEWGAME_PIN = 14;

LiquidCrystal_PCF8574 lcd(0x27);  // set the LCD address to 0x27 for a 16 chars and 2 line display
Bounce trig = Bounce(TRIGGER_PIN, 10);
Bounce newgame = Bounce(NEWGAME_PIN, 10);

void setup()
{
  pinMode(TRIGGER_PIN, INPUT_PULLUP);
  pinMode(NEWGAME_PIN, INPUT_PULLUP);
  lcd.begin(16, 2);
  lcd.setBacklight(true);
  lcd.print(" ROZPOCZNIJ GRE");
}

bool isSeedSet = false;
bool isGameStarted = false;
int lastPosRow, lastPosCol, currentPosRow, currentPosCol;

void loop()
{
  if(isGameStarted && trig.update() && trig.fallingEdge()) {
    lcd.setCursor(currentPosCol++, currentPosRow);
    lcd.print("O");
    if(currentPosCol >= 16) {
      currentPosRow++;
      currentPosCol = 0;
    }

    if(currentPosCol == lastPosCol && currentPosRow == lastPosRow) {
      isGameStarted = false;
    }
  }

  if(newgame.update() && newgame.fallingEdge()) {
    if(!isSeedSet) {
      isSeedSet = true;
      srand(micros());
    }

    isGameStarted = true;
    lastPosRow = rand() % 2;
    if(lastPosRow)
      lastPosCol = 1 + rand() % 15;
    else
      lastPosCol = 8 + rand() % 8;
      
    lcd.clear();
    lcd.setCursor(lastPosCol, lastPosRow);
    lcd.print("<");
    currentPosRow = currentPosCol = 0;
    lcd.setCursor(0,0);
  }
}
